@@ -1,6 +1,6 @@
 /************************************************************************
  * tstring.c      "Translated string" wrappers for dopewars             *
- * Copyright (C)  1998-2004  Ben Webb                                   *
+ * Copyright (C)  1998-2005  Ben Webb                                   *
  *                Email: benwebb@users.sf.net                           *
  *                WWW: http://dopewars.sourceforge.net/                 *
  *                                                                      *
@@ -158,8 +158,8 @@ void GetNextFormat(guint *Index, gchar *str, int *StartPos,
 
 gchar *HandleTFmt(gchar *format, va_list va)
 {
-  int StrInd, StartPos, EndPos, FmtPos, Wid, Prec;
-  guint i, ArgNum, DefaultArgNum;
+  int StrInd, StartPos, EndPos, FmtPos, Wid, Prec, ArgNum, DefaultArgNum;
+  guint i;
   char Code[3], Type;
   gchar *retstr, *fstr;
   GString *string, *tmpfmt;
@@ -277,7 +277,7 @@ void dpg_print(gchar *format, ...)
   va_start(ap, format);
   retstr = HandleTFmt(format, ap);
   va_end(ap);
-  g_print(retstr);
+  g_print("%s", retstr);
   g_free(retstr);
 }
 
