@@ -1,6 +1,6 @@
 /************************************************************************
  * winmain.c      Startup code and support for the Win32 platform       *
- * Copyright (C)  1998-2004  Ben Webb                                   *
+ * Copyright (C)  1998-2005  Ben Webb                                   *
  *                Email: benwebb@users.sf.net                           *
  *                WWW: http://dopewars.sourceforge.net/                 *
  *                                                                      *
@@ -62,8 +62,7 @@ static void ServerLogMessage(const gchar *log_domain,
 
   text = GetLogString(log_level, message);
   if (text) {
-    g_string_append(text, "\n");
-    g_print(text->str);
+    g_print("%s\n", text->str);
     g_string_free(text, TRUE);
   }
 }
@@ -112,7 +111,7 @@ static void LogFileStart()
 static void LogFilePrintFunc(const gchar *string)
 {
   if (LogFile) {
-    fprintf(LogFile, string);
+    fputs(string, LogFile);
     fflush(LogFile);
   }
 }
@@ -185,6 +184,9 @@ static gchar *GetWindowsLocale(void)
     break;
   case LANG_FRENCH:
     strcat(langenv, "fr");
+    if (sublang == SUBLANG_FRENCH_CANADIAN) {
+      strcat(langenv, "_CA");
+    }
     break;
   case LANG_GERMAN:
     strcat(langenv, "de");
@@ -194,6 +196,9 @@ static gchar *GetWindowsLocale(void)
     break;
   case LANG_SPANISH:
     strcat(langenv, "es");
+    if (sublang == SUBLANG_SPANISH) {
+      strcat(langenv, "_ES");
+    }
     break;
   case LANG_NORWEGIAN:
     if (sublang == SUBLANG_NORWEGIAN_NYNORSK) {
