@@ -1,7 +1,7 @@
 /************************************************************************
  * util.h         Shared functions for Win32 installer programs         *
- * Copyright (C)  2001-2002  Ben Webb                                   *
- *                Email: ben@bellatrix.pcl.ox.ac.uk                     *
+ * Copyright (C)  2001-2004  Ben Webb                                   *
+ *                Email: benwebb@users.sf.net                           *
  *                WWW: http://dopewars.sourceforge.net/                 *
  *                                                                      *
  * This program is free software; you can redistribute it and/or        *
@@ -87,6 +87,8 @@ void bstr_append_windir(bstr *str);
 void bstr_append_curdir(bstr *str);
 void bstr_assign_windir(bstr *str);
 void bstr_assign_curdir(bstr *str);
+void bstr_assign_progfilesdir(bstr *str);
+void bstr_append_progfilesdir(bstr *str);
 
 void DisplayError(const char *errtext, BOOL addsyserr, BOOL fatal);
 void AddInstFiles(char *filename, DWORD filesize, InstFiles **lastpt,
